@@ -21,7 +21,6 @@
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 import imaplib
-import base64
 import re
 import os
 import time
@@ -29,21 +28,14 @@ import socket
 import StringIO
 import rfc822
 import getpass
-import email.Encoders
-import email.MIMEBase
-import email.MIMEMultipart
-import email.Parser
+import email
 
 import duplicity.backend
 from duplicity import globals
 from duplicity import log
-from duplicity.errors import *
+from duplicity.errors import * #@UnusedWildImport
 
 
-# Name of the imap folder where we want to store backups.
-# Can be changed with a command line argument.
-imap_mailbox = "INBOX"
-
 class ImapBackend(duplicity.backend.Backend):
     def __init__(self, parsed_url):
         duplicity.backend.Backend.__init__(self, parsed_url)
@@ -62,7 +54,10 @@ class ImapBackend(duplicity.backend.Backend):
 
         #  Set the password
         if ( not parsed_url.password ):
-            password = getpass.getpass("Enter account password: ")
+            if os.environ.has_key('IMAP_PASSWORD'):
+                password = os.environ.get('IMAP_PASSWORD')
+            else:
+                password = getpass.getpass("Enter account password: ")
         else:
             password = parsed_url.password
 
@@ -96,12 +91,12 @@ class ImapBackend(duplicity.backend.Backend):
         #  Login
         if (not(globals.imap_full_address)):
             self._conn.login(self._username, self._password)
-            self._conn.select(imap_mailbox)
+            self._conn.select(globals.imap_mailbox)
             log.Info("IMAP connected")
         else:
-           self._conn.login(self._username + "@" + parsed_url.hostname, self._password)
-           self._conn.select(imap_mailbox)
-           log.Info("IMAP connected")
+            self._conn.login(self._username + "@" + parsed_url.hostname, self._password)
+            self._conn.select(globals.imap_mailbox)
+            log.Info("IMAP connected")
 
 
     def _prepareBody(self,f,rname):
@@ -136,8 +131,8 @@ class ImapBackend(duplicity.backend.Backend):
                 body=self._prepareBody(f,remote_filename)
                 # If we don't select the IMAP folder before
                 # append, the message goes into the INBOX.
-                self._conn.select(imap_mailbox)
-                self._conn.append(imap_mailbox,None,None,body)
+                self._conn.select(globals.imap_mailbox)
+                self._conn.append(globals.imap_mailbox, None, None, body)
                 break
             except (imaplib.IMAP4.abort, socket.error, socket.sslerror):
                 allowedTimeout -= 1
@@ -161,7 +156,7 @@ class ImapBackend(duplicity.backend.Backend):
             allowedTimeout = 2880
         while allowedTimeout > 0:
             try:
-                self._conn.select(imap_mailbox)
+                self._conn.select(globals.imap_mailbox)
                 (result,list) = self._conn.search(None, 'Subject', remote_filename)
                 if result != "OK":
                     raise Exception(list[0])
@@ -204,7 +199,7 @@ class ImapBackend(duplicity.backend.Backend):
 
     def list(self):
         ret = []
-        (result,list) = self._conn.select(imap_mailbox)
+        (result,list) = self._conn.select(globals.imap_mailbox)
         if result != "OK":
             raise BackendException(list[0])
 
@@ -252,7 +247,7 @@ class ImapBackend(duplicity.backend.Backend):
     def delete(self, filename_list):
         assert len(filename_list) > 0
         for filename in filename_list:
-            list = self._imapf(self._conn.search,None,"(HEADER, Subject %s)"%filename)
+            list = self._imapf(self._conn.search,None,"(SUBJECT %s)"%filename)
             list = list[0].split()
             if len(list)==0 or list[0]=="":raise Exception("no such mail with subject '%s'"%filename)
             self._delete_single_mail(list[0])
@@ -261,7 +256,7 @@ class ImapBackend(duplicity.backend.Backend):
         log.Notice("IMAP expunged %s files" % len(list))
 
     def close(self):
-        self._conn.select(imap_mailbox)
+        self._conn.select(globals.imap_mailbox)
         self._conn.close()
         self._conn.logout()
 
