@@ -32,7 +32,7 @@ import duplicity.backend
 from duplicity import globals
 from duplicity import log
 from duplicity import pexpect
-from duplicity.errors import *
+from duplicity.errors import * #@UnusedWildImport
 
 class SSHBackend(duplicity.backend.Backend):
     """This backend copies files using scp.  List not supported"""
@@ -78,7 +78,6 @@ class SSHBackend(duplicity.backend.Backend):
                 time.sleep(30)
             log.Info("Running '%s' (attempt #%d)" % (commandline, n))
             child = pexpect.spawn(commandline, timeout = None)
-            cmdloc = 0
             if globals.ssh_askpass:
                 state = "authorizing"
             else:
@@ -145,14 +144,14 @@ class SSHBackend(duplicity.backend.Backend):
     def run_sftp_command(self, commandline, commands):
         """ Run an sftp command, responding to password prompts, passing commands from list """
         maxread = 2000 # expect read buffer size
-        responses = ["(?i)timeout, server not responding",
+        responses = [pexpect.EOF,
+                     "(?i)timeout, server not responding",
                      "sftp>",
                      "(?i)pass(word|phrase .*):",
                      "(?i)permission denied",
                      "authenticity",
                      "(?i)no such file or directory"]
-        max_response_len = max([len(p) for p in responses])
-        responses = [pexpect.EOF] + responses
+        max_response_len = max([len(p) for p in responses[1:]])
         for n in range(1, globals.num_retries+1):
             if n > 1:
                 # sleep before retry
@@ -198,19 +197,40 @@ class SSHBackend(duplicity.backend.Backend):
         raise BackendException("Error running '%s'" % commandline)
 
     def put(self, source_path, remote_filename = None):
+        if globals.use_scp:
+            self.put_scp(source_path, remote_filename = remote_filename)
+        else:
+            self.put_sftp(source_path, remote_filename = remote_filename)
+
+    def put_sftp(self, source_path, remote_filename = None):
         """Use sftp to copy source_dir/filename to remote computer"""
         if not remote_filename:
             remote_filename = source_path.get_filename()
-        commands = ["put %s %s%s" %
+        commands = ["put \"%s\" \"%s%s\"" %
                     (source_path.name, self.remote_prefix, remote_filename)]
         commandline = ("%s %s %s" % (globals.sftp_command,
                                      globals.ssh_options,
                                      self.host_string))
         self.run_sftp_command(commandline, commands)
 
+    def put_scp(self, source_path, remote_filename = None):
+        """Use scp to copy source_dir/filename to remote computer"""
+        if not remote_filename:
+            remote_filename = source_path.get_filename()
+        commandline = "%s %s %s %s:%s%s" % \
+            (globals.scp_command, globals.ssh_options, source_path.name, self.host_string,
+             self.remote_prefix, remote_filename)
+        self.run_scp_command(commandline)
+
     def get(self, remote_filename, local_path):
+        if globals.use_scp:
+            self.get_scp(remote_filename, local_path)
+        else:
+            self.get_sftp(remote_filename, local_path)
+
+    def get_sftp(self, remote_filename, local_path):
         """Use sftp to get a remote file"""
-        commands = ["get %s%s %s" %
+        commands = ["get \"%s%s\" \"%s\"" %
                     (self.remote_prefix, remote_filename, local_path.name)]
         commandline = ("%s %s %s" % (globals.sftp_command,
                                      globals.ssh_options,
@@ -221,6 +241,17 @@ class SSHBackend(duplicity.backend.Backend):
             raise BackendException("File %s not found locally after get "
                                    "from backend" % local_path.name)
 
+    def get_scp(self, remote_filename, local_path):
+        """Use scp to get a remote file"""
+        commandline = "%s %s %s:%s%s %s" % \
+            (globals.scp_command, globals.ssh_options, self.host_string, self.remote_prefix,
+             remote_filename, local_path.name)
+        self.run_scp_command(commandline)
+        local_path.setdata()
+        if not local_path.exists():
+            raise BackendException("File %s not found locally after get "
+                                   "from backend" % local_path.name)
+
     def list(self):
         """
         List files available for scp
@@ -229,8 +260,8 @@ class SSHBackend(duplicity.backend.Backend):
         files with newlines in them, as the embedded newlines cannot
         be distinguished from the file boundaries.
         """
-        commands = ["mkdir %s" % (self.remote_dir,),
-                    "cd %s" % (self.remote_dir,),
+        commands = ["mkdir \"%s\"" % (self.remote_dir,),
+                    "cd \"%s\"" % (self.remote_dir,),
                     "ls -1"]
         commandline = ("%s %s %s" % (globals.sftp_command,
                                      globals.ssh_options,
@@ -244,9 +275,9 @@ class SSHBackend(duplicity.backend.Backend):
         """
         Runs sftp rm to delete files.  Files must not require quoting.
         """
-        commands = ["cd %s" % (self.remote_dir,)]
+        commands = ["cd \"%s\"" % (self.remote_dir,)]
         for fn in filename_list:
-            commands.append("rm %s" % fn)
+            commands.append("rm \"%s\"" % fn)
         commandline = ("%s %s %s" % (globals.sftp_command, globals.ssh_options, self.host_string))
         self.run_sftp_command(commandline, commands)
 
