@@ -21,7 +21,7 @@
 
 """Classes and functions on collections of backup volumes"""
 
-import gzip, types
+import types
 import gettext
 
 from duplicity import log
@@ -49,7 +49,8 @@ class BackupSet:
         self.remote_manifest_name = None            # full name of remote manifest
         self.local_manifest_path = None             # full path to local manifest
         self.time = None                            # will be set if is full backup set
-        self.start_time, self.end_time = None, None # will be set if inc
+        self.start_time = None                      # will be set if inc
+        self.end_time = None                        # will be set if inc
         self.partial = False                        # true if a partial backup
 
     def is_complete(self):
@@ -103,7 +104,8 @@ class BackupSet:
         assert not self.info_set
         self.type = pr.type
         self.time = pr.time
-        self.start_time, self.end_time = pr.start_time, pr.end_time
+        self.start_time = pr.start_time
+        self.end_time = pr.end_time
         self.time = pr.time
         self.partial = pr.partial
         self.info_set = True
@@ -118,8 +120,10 @@ class BackupSet:
 
         for local_filename in globals.archive_dir.listdir():
             pr = file_naming.parse(local_filename)
-            if (pr and pr.manifest and pr.type == self.type and
-                pr.time == self.time and pr.start_time == self.start_time
+            if (pr and pr.manifest
+                and pr.type == self.type
+                and pr.time == self.time
+                and pr.start_time == self.start_time
                 and pr.end_time == self.end_time):
                 self.local_manifest_path = \
                               globals.archive_dir.append(local_filename)
@@ -127,11 +131,31 @@ class BackupSet:
 
     def delete(self):
         """
-        Remove all files in set
+        Remove all files in set, both local and remote
         """
-        l = self.get_filenames()
-        l.reverse() # delete starting with manifest
-        self.backend.delete(l)
+        rfn = self.get_filenames()
+        rfn.reverse()
+        try:
+            self.backend.delete(rfn)
+        except:
+            log.Debug("BackupSet.delete: missing %s" % rfn)
+            pass
+        for lfn in globals.archive_dir.listdir():
+            pr = file_naming.parse(lfn)
+            if (pr
+                and pr.time == self.time
+                and pr.start_time == self.start_time
+                and pr.end_time == self.end_time
+                and pr.type != "new-sig" ):
+                # do not remove new sigs from the cache:
+                # they aren't removed from the remote archive,
+                # and subsequent backups will have to resync
+                # which is bad if running non-interactive with encrypt-key 
+                try:
+                    globals.archive_dir.append(lfn).delete()
+                except:
+                    log.Debug("BackupSet.delete: missing %s" % lfn)
+                    pass
 
     def __str__(self):
         """
@@ -194,7 +218,9 @@ class BackupSet:
         try:
             manifest_buffer = self.backend.get_data(self.remote_manifest_name)
         except GPGError, message:
-            if "secret key not available" in message.args[0]:
+            #TODO: We check for gpg v1 and v2 messages, should be an error code.
+            if ("secret key not available" in message.args[0] or
+                "No secret key" in message.args[0]):
                 return None
             else:
                 raise
@@ -531,7 +557,8 @@ class CollectionsStatus:
         """
         Make new object.  Does not set values
         """
-        self.backend, self.archive_dir = backend, archive_dir
+        self.backend = backend
+        self.archive_dir = archive_dir
 
         # Will hold (signature chain, backup chain) pair of active
         # (most recent) chains
@@ -540,10 +567,11 @@ class CollectionsStatus:
         # These should be sorted by end_time
         self.all_backup_chains = None
         self.other_backup_chains = None
-        self.other_sig_chains = None
+        self.all_sig_chains = None
 
         # Other misc paths and sets which shouldn't be there
-        self.orphaned_sig_names = None
+        self.local_orphaned_sig_names = []
+        self.remote_orphaned_sig_names = []
         self.orphaned_backup_sets = None
         self.incomplete_backup_sets = None
 
@@ -558,6 +586,7 @@ class CollectionsStatus:
              "archive-dir %s" % (self.archive_dir,)]
 
         for i in range(len(self.other_backup_chains)):
+            # A bit of a misnomer.  Chain might have a sig.
             l.append("chain-no-sig %d" % (i,))
             l += self.other_backup_chains[i].to_log_info(' ')
 
@@ -578,21 +607,21 @@ class CollectionsStatus:
              "-----------------",
              _("Connecting with backend: %s") %
              (self.backend.__class__.__name__,),
-             _("Archive dir: %s") % (self.archive_dir,)]
+             _("Archive dir: %s") % (self.archive_dir.name,)]
 
         l.append("\n" +
-                 gettext.ngettext("Found %d backup chain without signatures.",
-                                  "Found %d backup chains without signatures.",
+                 gettext.ngettext("Found %d secondary backup chain.",
+                                  "Found %d secondary backup chains.",
                                   len(self.other_backup_chains))
                  % len(self.other_backup_chains))
         for i in range(len(self.other_backup_chains)):
-            l.append(_("Signature-less chain %d of %d:") %
+            l.append(_("Secondary chain %d of %d:") %
                      (i+1, len(self.other_backup_chains)))
             l.append(str(self.other_backup_chains[i]))
             l.append("")
 
         if self.matched_chain_pair:
-            l.append("\n" + _("Found a complete backup chain with matching "
+            l.append("\n" + _("Found primary backup chain with matching "
                      "signature chain:"))
             l.append(str(self.matched_chain_pair[1]))
         else:
@@ -607,8 +636,9 @@ class CollectionsStatus:
                                       "and %d incomplete backup sets.",
                                       len(self.incomplete_backup_sets))
                      % (len(self.incomplete_backup_sets),))
-            l.append(_("These may be deleted by running duplicity with the "
-                       "--cleanup option."))
+            # TRANSL: "cleanup" is a hard-coded command, so do not translate it
+            l.append(_('These may be deleted by running duplicity with the '
+                       '"cleanup" command.'))
         else:
             l.append(_("No orphaned or incomplete backup sets found."))
 
@@ -645,6 +675,7 @@ class CollectionsStatus:
             if pr and pr.partial:
                 partials.append(local_filename)
 
+        # get various backup sets and chains
         (backup_chains, self.orphaned_backup_sets,
                  self.incomplete_backup_sets) = \
                  self.get_backup_chains(partials + backend_filename_list)
@@ -653,12 +684,10 @@ class CollectionsStatus:
 
         assert len(backup_chains) == len(self.all_backup_chains), "get_sorted_chains() did something more than re-ordering"
 
-        local_sig_chains, local_orphaned_sig_names = \
+        local_sig_chains, self.local_orphaned_sig_names = \
                             self.get_signature_chains(True)
-        remote_sig_chains, remote_orphaned_sig_names = \
+        remote_sig_chains, self.remote_orphaned_sig_names = \
                             self.get_signature_chains(False, filelist = backend_filename_list)
-        self.orphaned_sig_names = (local_orphaned_sig_names +
-                                   remote_orphaned_sig_names)
         self.set_matched_chain_pair(local_sig_chains + remote_sig_chains,
                                     backup_chains)
         self.warn(sig_chain_warning)
@@ -673,12 +702,12 @@ class CollectionsStatus:
         latest backup chain, use the local sig chain (it does not need
         to be downloaded).
         """
-        self.other_sig_chains = sig_chains
+        sig_chains = sig_chains and self.get_sorted_chains(sig_chains)
+        self.all_sig_chains = sig_chains
         self.other_backup_chains = backup_chains[:]
         self.matched_chain_pair = None
         if sig_chains and backup_chains:
             latest_backup_chain = backup_chains[-1]
-            sig_chains = self.get_sorted_chains(sig_chains)
             for i in range(len(sig_chains)-1, -1, -1):
                 if sig_chains[i].end_time == latest_backup_chain.end_time:
                     pass
@@ -697,19 +726,9 @@ class CollectionsStatus:
                 if self.matched_chain_pair == None:
                     self.matched_chain_pair = (sig_chains[i], latest_backup_chain)
 
-                del sig_chains[i]
                 break
 
         if self.matched_chain_pair:
-            # if we have local and remote sig chains, remove both from the other_sig_chains list
-            matched_sig_chain = self.matched_chain_pair[0]
-            if len(self.other_sig_chains) > 1:
-                for sig_chain in self.other_sig_chains[1:]:
-                    if (sig_chain.islocal() != matched_sig_chain.islocal() and
-                        sig_chain.start_time == matched_sig_chain.start_time and
-                        sig_chain.end_time == matched_sig_chain.end_time):
-                        self.other_sig_chains.remove(sig_chain)
-            self.other_sig_chains.remove(matched_sig_chain)
             self.other_backup_chains.remove(self.matched_chain_pair[1])
 
     def warn(self, sig_chain_warning):
@@ -717,30 +736,33 @@ class CollectionsStatus:
         Log various error messages if find incomplete/orphaned files
         """
         assert self.values_set
-        if self.orphaned_sig_names:
-            log.Warn(gettext.ngettext("Warning, found the following orphaned "
+
+        if self.local_orphaned_sig_names:
+            log.Warn(gettext.ngettext("Warning, found the following local orphaned "
                                       "signature file:",
-                                      "Warning, found the following orphaned "
+                                      "Warning, found the following local orphaned "
                                       "signature files:",
-                                      len(self.orphaned_sig_names))
-                     + "\n" + "\n".join(self.orphaned_sig_names),
+                                      len(self.local_orphaned_sig_names))
+                     + "\n" + "\n".join(self.local_orphaned_sig_names),
                      log.WarningCode.orphaned_sig)
-        if self.other_sig_chains and sig_chain_warning:
-            if self.matched_chain_pair:
-                log.Warn(gettext.ngettext("Warning, found an unnecessary "
-                                          "signature chain",
-                                          "Warning, found unnecessary "
-                                          "signature chains",
-                                          len(self.other_sig_chains))
-                     + "\n" + "\n".join([f.fullsig for f in self.other_sig_chains]),
-                     log.WarningCode.unnecessary_sig)
-            else:
-                log.Warn(_("Warning, found signatures but no corresponding "
-                           "backup files"), log.WarningCode.unmatched_sig)
+
+        if self.remote_orphaned_sig_names:
+            log.Warn(gettext.ngettext("Warning, found the following remote orphaned "
+                                      "signature file:",
+                                      "Warning, found the following remote orphaned "
+                                      "signature files:",
+                                      len(self.remote_orphaned_sig_names))
+                     + "\n" + "\n".join(self.remote_orphaned_sig_names),
+                     log.WarningCode.orphaned_sig)
+
+        if self.all_sig_chains and sig_chain_warning and not self.matched_chain_pair:
+            log.Warn(_("Warning, found signatures but no corresponding "
+                       "backup files"), log.WarningCode.unmatched_sig)
 
         if self.incomplete_backup_sets:
             log.Warn(_("Warning, found incomplete backup sets, probably left "
                        "from aborted session"), log.WarningCode.incomplete_backup)
+
         if self.orphaned_backup_sets:
             log.Warn(gettext.ngettext("Warning, found the following orphaned "
                                       "backup file:",
@@ -755,7 +777,7 @@ class CollectionsStatus:
         """
         Split given filename_list into chains
 
-        Return value will be pair (list of chains, list of sets, list
+        Return value will be tuple (list of chains, list of sets, list
         of incomplete sets), where the list of sets will comprise sets
         not fitting into any chain, and the incomplete sets are sets
         missing files.
@@ -930,13 +952,34 @@ class CollectionsStatus:
         else:
             return self.all_backup_chains[0] # no chains are old enough
 
-    def cleanup_signatures(self):
+    def get_signature_chain_at_time(self, time):
         """
-        Delete unnecessary older signatures
-        """
-        map(SignatureChain.delete, self.other_sig_chains)
+        Return signature chain covering specified time
 
-    def get_extraneous(self):
+        Tries to find the signature chain covering the given time.  If
+        there is none, return the earliest chain before, and failing
+        that, the earliest chain.
+        """
+        if not self.all_sig_chains:
+            raise CollectionsError("No signature chains found")
+
+        covering_chains = filter(lambda c: c.start_time <= time <= c.end_time,
+                                 self.all_sig_chains)
+        if covering_chains:
+            return covering_chains[-1] # prefer local if multiple sig chains
+
+        old_chains = filter(lambda c: c.end_time < time,
+                            self.all_sig_chains)
+        if old_chains:
+            return old_chains[-1]
+        else:
+            # no chains are old enough, give oldest and warn user
+            oldest = self.all_sig_chains[0]
+            if time < oldest.start_time:
+                log.Warn(_("No signature chain for the requested time.  Using oldest available chain, starting at time %s.") % dup_time.timetopretty(oldest.start_time), log.WarningCode.no_sig_for_time, dup_time.timetostring(oldest.start_time))
+            return oldest
+
+    def get_extraneous(self, extra_clean):
         """
         Return list of the names of extraneous duplicity files
 
@@ -945,14 +988,28 @@ class CollectionsStatus:
         complete backup set, or current signature chain.
         """
         assert self.values_set
-        filenames = []
-        ext_containers = (self.other_sig_chains, self.orphaned_backup_sets,
-                          self.incomplete_backup_sets)
-        for set_or_chain_list in ext_containers:
-            for set_or_chain in set_or_chain_list:
-                filenames.extend(set_or_chain.get_filenames())
-        filenames.extend(self.orphaned_sig_names)
-        return filenames
+        local_filenames = []
+        remote_filenames = []
+        ext_containers = self.orphaned_backup_sets + self.incomplete_backup_sets
+        if extra_clean:
+            old_sig_chains = self.all_sig_chains[:]
+            if self.matched_chain_pair:
+                matched_sig_chain = self.matched_chain_pair[0]
+                for sig_chain in self.all_sig_chains:
+                    print sig_chain.start_time, matched_sig_chain.start_time, 
+                    print sig_chain.end_time, matched_sig_chain.end_time
+                    if (sig_chain.start_time == matched_sig_chain.start_time and
+                        sig_chain.end_time == matched_sig_chain.end_time):
+                        old_sig_chains.remove(sig_chain)
+            ext_containers += old_sig_chains
+        for set_or_chain in ext_containers:
+            if set_or_chain.backend:
+                remote_filenames.extend(set_or_chain.get_filenames())
+            else:
+                local_filenames.extend(set_or_chain.get_filenames())
+        local_filenames += self.local_orphaned_sig_names
+        remote_filenames += self.remote_orphaned_sig_names
+        return local_filenames, remote_filenames
 
     def sort_sets(self, setlist):
         """Return new list containing same elems of setlist, sorted by time"""
