@@ -21,7 +21,7 @@
 
 """Manage temporary files"""
 
-import tempfile, os, sys, errno
+import os, sys
 
 from duplicity import log
 from duplicity import path
@@ -175,17 +175,13 @@ class FileobjHooked:
         tgt = self.dirpath.append(self.remname)
         src_iter = SrcIter(src)
         if pr.compressed:
-            gpg.GzipWriteFile(src_iter, tgt.name,
-                              size = sys.maxint / 2)
+            gpg.GzipWriteFile(src_iter, tgt.name, size = sys.maxint)
         elif pr.encrypted:
-            gpg.GPGWriteFile(src_iter, tgt.name,
-                             globals.gpg_profile, size = sys.maxint / 2)
+            gpg.GPGWriteFile(src_iter, tgt.name, globals.gpg_profile, size = sys.maxint)
         else:
-            if src.name != tgt.name:
-                assert not os.system("ln -s %s %s" % (src.name, tgt.name))
-        globals.backend.put(tgt)
-        if src.name != tgt.name:
-            os.unlink(tgt.name)
+            os.system("cp -p %s %s" % (src.name, tgt.name))
+        globals.backend.put(tgt) #@UndefinedVariable
+        os.unlink(tgt.name)
 
     def to_final(self):
         """
@@ -196,7 +192,7 @@ class FileobjHooked:
         src_iter = SrcIter(src)
         pr = file_naming.parse(self.permname)
         if pr.compressed:
-            gpg.GzipWriteFile(src_iter, tgt.name, size = sys.maxint / 2)
+            gpg.GzipWriteFile(src_iter, tgt.name, size = sys.maxint)
             os.unlink(src.name)
         else:
             os.rename(src.name, tgt.name)
@@ -241,7 +237,7 @@ class SrcIter:
             res = Block(self.fp.read(size))
         except:
             log.FatalError(_("Failed to read %s: %s") %
-                           (src.name, sys.exc_info()),
+                           (self.src.name, sys.exc_info()),
                            log.ErrorCode.generic)
         if not res.data:
             self.fp.close()
