@@ -7,7 +7,7 @@
 #
 # Duplicity is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 3 of the License, or (at your
+# Free Software Foundation; either version 2 of the License, or (at your
 # option) any later version.
 #
 # Duplicity is distributed in the hope that it will be useful, but
@@ -22,7 +22,8 @@
 """Provide time related exceptions and functions"""
 
 import time, types, re
-import globals
+
+from duplicity import globals
 
 
 class TimeException(Exception):
@@ -62,7 +63,7 @@ the day).""")
 def setcurtime(time_in_secs = None):
     """Sets the current time in curtime and curtimestr"""
     global curtime, curtimestr
-    t = time_in_secs or long(time.time())
+    t = time_in_secs or curtime or long(time.time()) # only set from NOW once
     assert type(t) in (types.LongType, types.IntType)
     curtime, curtimestr = t, timetostring(t)
 
